﻿using System;
using System.IO;             //for load-save functions (file writing)
using System.Windows.Forms;  //for GUI forms
using Scrabble;

namespace Scrabble
{
    //Contains event handlers for the game Menu (plus all IO methods)
    public partial class MainForm
    {
        public bool solver = true;
        public short difficulty = 2;

        //File -> Exit
        private void exitToolStripMenuItem_Click(object sender, EventArgs e) { Application.Exit(); }

        //File -> New Game
        private void newGameF2ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            game = new Board();
            this.listBox1.Items.Clear();
            putBoard();
            putLetters();

            if (!solver)
            {
                letterBag = Words.scramble("**EEEEEEEEEEEEAAAAAAAAAIIIIIIIIIOOOOOOOONNNNNNRRRRRRTTTTTTLLLLSSSSUUUUDDDDGGGBBCCMMPPFFHHVVWWYYKJXQZ");
                game.letters = letterBag.Substring(0, 7);
                putLetters();
                letterBag = letterBag.Substring(7, letterBag.Length - 7);
            }
        }

        //File -> Load
        private void loadGameToolStripMenuItem_Click(object sender, EventArgs e)
        { openFileDialog1.ShowDialog(); }

        //File -> Load and okayed
        private void openFileDialog1_FileOk(object sender, System.ComponentModel.CancelEventArgs e)
        { load(openFileDialog1.FileName); } 

        //File -> Save
        private void saveGameToolStripMenuItem_Click(object sender, EventArgs e)
        {
            getLetters();
            storeBoard();
            saveFileDialog1.ShowDialog();
        }

        //File -> Save and okayed
        private void saveFileDialog1_FileOk(object sender, System.ComponentModel.CancelEventArgs e)
        {
            save(saveFileDialog1.FileName);
        }

        //Game -> Difficulty -> Think Ahead
        private void hardToolStripMenuItem_Click(object sender, EventArgs e)
        {
            difficulty = 3;
            setMenu();
        }

        //Game -> Difficulty -> Expert
        private void expertToolStripMenuItem_Click(object sender, EventArgs e)
        {
            difficulty = 2;
            setMenu();
        }

        //Game -> Difficulty -> Average
        private void averageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            difficulty = 1;
            setMenu();
        }

        //Game -> Difficulty -> Novice
        private void noviceToolStripMenuItem_Click(object sender, EventArgs e)
        {
            difficulty = 0;
            setMenu();
        }

        //Mode -> Game
        private void gameToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (solver)
            {
                solver = false;
                newGameF2ToolStripMenuItem_Click(sender, e);
            }
            solver = false;
            setMenu();
        }

        //Mode -> Solver
        private void solverToolStripMenuItem_Click(object sender, EventArgs e)
        {
            solver = true;
            setMenu();
        }

        //Adjusts the main menu so that the right options are checked and the right items are enabled
        private void setMenu()
        {
            //Set GUI Components
            this.listBox1.Visible = solver;
            this.button1.Visible = solver;

            //Set Mode Menu
            this.solverToolStripMenuItem.Checked = solver;
            this.gameToolStripMenuItem.Checked = !solver;

            //Set Game Menu
            this.hintToolStripMenuItem.Enabled = !solver;
            this.undoMoveToolStripMenuItem.Enabled = !solver;

            //Set Difficulty subMenu
            this.noviceToolStripMenuItem.Checked = false;
            this.averageToolStripMenuItem.Checked = false;
            this.expertToolStripMenuItem.Checked = false;
            this.hardToolStripMenuItem.Checked = false;

            if (difficulty == 0)
                this.noviceToolStripMenuItem.Checked = true;
            else if (difficulty == 1)
                this.averageToolStripMenuItem.Checked = true;
            else if (difficulty == 3)
                this.hardToolStripMenuItem.Checked = true;
            else
                this.hardToolStripMenuItem.Checked = true;
        }

        //Saves the current game state or solver state
        private void save(string file)
        {
            if (File.Exists(file))
                File.Delete(file);
            StreamWriter outFile = File.CreateText(file);
            outFile.WriteLine(game.letters);

            for (int i = 0; i < 15; i++)
            {
                string line = "";

                for (int j = 0; j < 15; j++)
                    line += game.board[i, j];

                outFile.WriteLine(line);
            }

            outFile.WriteLine(difficulty);
            if (solver)
                outFile.WriteLine("Solver");
            else
            {
                outFile.WriteLine("Game");
                outFile.WriteLine(letterBag);
                //TODO Player Scores
            }
            outFile.Close();
        }

        //Load from file
        private void load(string file)
        {
            try
            {
                StreamReader inFile = File.OpenText(file);
                string[] lines = new string[18];

                for (int l = 0; l < 18; l++)
                    lines[l] = inFile.ReadLine();

                game.letters = lines[0];
                putLetters();
                for (int i = 1; i <= 15; i++)
                {
                    int j = 0;
                    foreach (char c in lines[i])
                        game.board[i - 1, j++] = c;
                }

                difficulty = Convert.ToInt16(lines[16]);
                solver = (lines[17] == "Solver");
                if (!solver)
                {
                    //TODO Player Scores
                }

                putBoard();

                setMenu();
            }
            catch (Exception e) { System.Console.WriteLine(e.Message); }
        }

        //Loads the dictionary
        private void loadDictionary()
        {
            //Add words to dictionary
            string line;
            StreamReader file = new StreamReader("dictionary.txt");
            while ((line = file.ReadLine()) != null)
                game.dictionary.Add(line);
            file.Close();
        }
    }
}