﻿using System;
using System.Drawing.Drawing2D;
using System.Drawing;        //for Text
using System.Windows.Forms;  //for GUI forms
using System.ComponentModel; //for BackgroundWorker (threading)
using System.Threading;      //for threading
using Scrabble;

namespace Scrabble
{
    public partial class MainForm : Form
    {
        public Board game;
        public BackgroundWorker calculator = new BackgroundWorker();
        public string letterBag;
        public int playerScore;
        public int computerScore;

        public MainForm() 
        {
            InitializeComponent();
            game = new Board();
            load("default");

            //Threading support
            calculator.DoWork += calculator_DoWork;
            calculator.RunWorkerCompleted += calculator_RunWorkerCompleted;
        }
        
        //Calculate button is clicked
        private void button1_Click(object sender, EventArgs e)
        {
            game = new Board();
            loadDictionary();
            getLetters();
            storeBoard();
            save("default");
            this.progressBar1.Visible = true;
            this.timer1.Start();

            calculator.RunWorkerAsync();
        }

        //Calculation Thread
        private void calculator_DoWork(object sender, DoWorkEventArgs e)
        {game.calculateResults();}

        //Post processing after thread finishes
        private void calculator_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        { 
            fillList();
            this.timer1.Stop();
            this.progressBar1.Visible = false;
        }

        //Timer tick - timer runs while thread is calculating
        private void timer1_Tick(object sender, EventArgs e)
        {
            this.progressBar1.Value = game.percentage;
        }

        //Selecting an item from the results listbox
        private void listBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            Board.result res = (Board.result)game.results[this.listBox1.SelectedIndex];
            game.placeResult(res);
            putBoard();
            game.restore();
        }

        //Fills the list box with recently calculated results
        private void fillList()
        {
            this.listBox1.Items.Clear();

            foreach (Board.result r in game.results)
                this.listBox1.Items.Add(r.pts + " " + r.word);
        }

        //Gets the 7 letters off the game board
        private void getLetters()
        {
            game.letters =
                this.textBox226.Text +
                this.textBox227.Text +
                this.textBox228.Text +
                this.textBox229.Text +
                this.textBox230.Text +
                this.textBox231.Text +
                this.textBox232.Text;

            //IODO error checking
        }

        //Puts a string of 7 letters onto the game board
        private void putLetters()
        {
            char[] c = game.letters.ToCharArray();
            if (c.Length == 7)
            {
                this.textBox226.Text = c[0].ToString();
                this.textBox227.Text = c[1].ToString();
                this.textBox228.Text = c[2].ToString();
                this.textBox229.Text = c[3].ToString();
                this.textBox230.Text = c[4].ToString();
                this.textBox231.Text = c[5].ToString();
                this.textBox232.Text = c[6].ToString();
            }
            else
            {
                this.textBox226.Text = "";
                this.textBox227.Text = "";
                this.textBox228.Text = "";
                this.textBox229.Text = "";
                this.textBox230.Text = "";
                this.textBox231.Text = "";
                this.textBox232.Text = "";            
            }
        }

        //Get board from textBoxes, put to char[,]
        private void storeBoard()
        {
            string[,] board = new string[15, 15];
            board[0, 0] = this.textBox1.Text;
            board[0, 1] = this.textBox2.Text;
            board[0, 2] = this.textBox3.Text;
            board[0, 3] = this.textBox4.Text;
            board[0, 4] = this.textBox5.Text;
            board[0, 5] = this.textBox6.Text;
            board[0, 6] = this.textBox7.Text;
            board[0, 7] = this.textBox8.Text;
            board[0, 8] = this.textBox9.Text;
            board[0, 9] = this.textBox10.Text;
            board[0, 10] = this.textBox11.Text;
            board[0, 11] = this.textBox12.Text;
            board[0, 12] = this.textBox13.Text;
            board[0, 13] = this.textBox14.Text;
            board[0, 14] = this.textBox15.Text;
            board[1, 0] = this.textBox16.Text;
            board[1, 1] = this.textBox17.Text;
            board[1, 2] = this.textBox18.Text;
            board[1, 3] = this.textBox19.Text;
            board[1, 4] = this.textBox20.Text;
            board[1, 5] = this.textBox21.Text;
            board[1, 6] = this.textBox22.Text;
            board[1, 7] = this.textBox23.Text;
            board[1, 8] = this.textBox24.Text;
            board[1, 9] = this.textBox25.Text;
            board[1, 10] = this.textBox26.Text;
            board[1, 11] = this.textBox27.Text;
            board[1, 12] = this.textBox28.Text;
            board[1, 13] = this.textBox29.Text;
            board[1, 14] = this.textBox30.Text;
            board[2, 0] = this.textBox31.Text;
            board[2, 1] = this.textBox32.Text;
            board[2, 2] = this.textBox33.Text;
            board[2, 3] = this.textBox34.Text;
            board[2, 4] = this.textBox35.Text;
            board[2, 5] = this.textBox36.Text;
            board[2, 6] = this.textBox37.Text;
            board[2, 7] = this.textBox38.Text;
            board[2, 8] = this.textBox39.Text;
            board[2, 9] = this.textBox40.Text;
            board[2, 10] = this.textBox41.Text;
            board[2, 11] = this.textBox42.Text;
            board[2, 12] = this.textBox43.Text;
            board[2, 13] = this.textBox44.Text;
            board[2, 14] = this.textBox45.Text;
            board[3, 0] = this.textBox46.Text;
            board[3, 1] = this.textBox47.Text;
            board[3, 2] = this.textBox48.Text;
            board[3, 3] = this.textBox49.Text;
            board[3, 4] = this.textBox50.Text;
            board[3, 5] = this.textBox51.Text;
            board[3, 6] = this.textBox52.Text;
            board[3, 7] = this.textBox53.Text;
            board[3, 8] = this.textBox54.Text;
            board[3, 9] = this.textBox55.Text;
            board[3, 10] = this.textBox56.Text;
            board[3, 11] = this.textBox57.Text;
            board[3, 12] = this.textBox58.Text;
            board[3, 13] = this.textBox59.Text;
            board[3, 14] = this.textBox60.Text;
            board[4, 0] = this.textBox61.Text;
            board[4, 1] = this.textBox62.Text;
            board[4, 2] = this.textBox63.Text;
            board[4, 3] = this.textBox64.Text;
            board[4, 4] = this.textBox65.Text;
            board[4, 5] = this.textBox66.Text;
            board[4, 6] = this.textBox67.Text;
            board[4, 7] = this.textBox68.Text;
            board[4, 8] = this.textBox69.Text;
            board[4, 9] = this.textBox70.Text;
            board[4, 10] = this.textBox71.Text;
            board[4, 11] = this.textBox72.Text;
            board[4, 12] = this.textBox73.Text;
            board[4, 13] = this.textBox74.Text;
            board[4, 14] = this.textBox75.Text;
            board[5, 0] = this.textBox76.Text;
            board[5, 1] = this.textBox77.Text;
            board[5, 2] = this.textBox78.Text;
            board[5, 3] = this.textBox79.Text;
            board[5, 4] = this.textBox80.Text;
            board[5, 5] = this.textBox81.Text;
            board[5, 6] = this.textBox82.Text;
            board[5, 7] = this.textBox83.Text;
            board[5, 8] = this.textBox84.Text;
            board[5, 9] = this.textBox85.Text;
            board[5, 10] = this.textBox86.Text;
            board[5, 11] = this.textBox87.Text;
            board[5, 12] = this.textBox88.Text;
            board[5, 13] = this.textBox89.Text;
            board[5, 14] = this.textBox90.Text;
            board[6, 0] = this.textBox91.Text;
            board[6, 1] = this.textBox92.Text;
            board[6, 2] = this.textBox93.Text;
            board[6, 3] = this.textBox94.Text;
            board[6, 4] = this.textBox95.Text;
            board[6, 5] = this.textBox96.Text;
            board[6, 6] = this.textBox97.Text;
            board[6, 7] = this.textBox98.Text;
            board[6, 8] = this.textBox99.Text;
            board[6, 9] = this.textBox100.Text;
            board[6, 10] = this.textBox101.Text;
            board[6, 11] = this.textBox102.Text;
            board[6, 12] = this.textBox103.Text;
            board[6, 13] = this.textBox104.Text;
            board[6, 14] = this.textBox105.Text;
            board[7, 0] = this.textBox106.Text;
            board[7, 1] = this.textBox107.Text;
            board[7, 2] = this.textBox108.Text;
            board[7, 3] = this.textBox109.Text;
            board[7, 4] = this.textBox110.Text;
            board[7, 5] = this.textBox111.Text;
            board[7, 6] = this.textBox112.Text;
            board[7, 7] = this.textBox113.Text;
            board[7, 8] = this.textBox114.Text;
            board[7, 9] = this.textBox115.Text;
            board[7, 10] = this.textBox116.Text;
            board[7, 11] = this.textBox117.Text;
            board[7, 12] = this.textBox118.Text;
            board[7, 13] = this.textBox119.Text;
            board[7, 14] = this.textBox120.Text;
            board[8, 0] = this.textBox121.Text;
            board[8, 1] = this.textBox122.Text;
            board[8, 2] = this.textBox123.Text;
            board[8, 3] = this.textBox124.Text;
            board[8, 4] = this.textBox125.Text;
            board[8, 5] = this.textBox126.Text;
            board[8, 6] = this.textBox127.Text;
            board[8, 7] = this.textBox128.Text;
            board[8, 8] = this.textBox129.Text;
            board[8, 9] = this.textBox130.Text;
            board[8, 10] = this.textBox131.Text;
            board[8, 11] = this.textBox132.Text;
            board[8, 12] = this.textBox133.Text;
            board[8, 13] = this.textBox134.Text;
            board[8, 14] = this.textBox135.Text;
            board[9, 0] = this.textBox136.Text;
            board[9, 1] = this.textBox137.Text;
            board[9, 2] = this.textBox138.Text;
            board[9, 3] = this.textBox139.Text;
            board[9, 4] = this.textBox140.Text;
            board[9, 5] = this.textBox141.Text;
            board[9, 6] = this.textBox142.Text;
            board[9, 7] = this.textBox143.Text;
            board[9, 8] = this.textBox144.Text;
            board[9, 9] = this.textBox145.Text;
            board[9, 10] = this.textBox146.Text;
            board[9, 11] = this.textBox147.Text;
            board[9, 12] = this.textBox148.Text;
            board[9, 13] = this.textBox149.Text;
            board[9, 14] = this.textBox150.Text;
            board[10, 0] = this.textBox151.Text;
            board[10, 1] = this.textBox152.Text;
            board[10, 2] = this.textBox153.Text;
            board[10, 3] = this.textBox154.Text;
            board[10, 4] = this.textBox155.Text;
            board[10, 5] = this.textBox156.Text;
            board[10, 6] = this.textBox157.Text;
            board[10, 7] = this.textBox158.Text;
            board[10, 8] = this.textBox159.Text;
            board[10, 9] = this.textBox160.Text;
            board[10, 10] = this.textBox161.Text;
            board[10, 11] = this.textBox162.Text;
            board[10, 12] = this.textBox163.Text;
            board[10, 13] = this.textBox164.Text;
            board[10, 14] = this.textBox165.Text;
            board[11, 0] = this.textBox166.Text;
            board[11, 1] = this.textBox167.Text;
            board[11, 2] = this.textBox168.Text;
            board[11, 3] = this.textBox169.Text;
            board[11, 4] = this.textBox170.Text;
            board[11, 5] = this.textBox171.Text;
            board[11, 6] = this.textBox172.Text;
            board[11, 7] = this.textBox173.Text;
            board[11, 8] = this.textBox174.Text;
            board[11, 9] = this.textBox175.Text;
            board[11, 10] = this.textBox176.Text;
            board[11, 11] = this.textBox177.Text;
            board[11, 12] = this.textBox178.Text;
            board[11, 13] = this.textBox179.Text;
            board[11, 14] = this.textBox180.Text;
            board[12, 0] = this.textBox181.Text;
            board[12, 1] = this.textBox182.Text;
            board[12, 2] = this.textBox183.Text;
            board[12, 3] = this.textBox184.Text;
            board[12, 4] = this.textBox185.Text;
            board[12, 5] = this.textBox186.Text;
            board[12, 6] = this.textBox187.Text;
            board[12, 7] = this.textBox188.Text;
            board[12, 8] = this.textBox189.Text;
            board[12, 9] = this.textBox190.Text;
            board[12, 10] = this.textBox191.Text;
            board[12, 11] = this.textBox192.Text;
            board[12, 12] = this.textBox193.Text;
            board[12, 13] = this.textBox194.Text;
            board[12, 14] = this.textBox195.Text;
            board[13, 0] = this.textBox196.Text;
            board[13, 1] = this.textBox197.Text;
            board[13, 2] = this.textBox198.Text;
            board[13, 3] = this.textBox199.Text;
            board[13, 4] = this.textBox200.Text;
            board[13, 5] = this.textBox201.Text;
            board[13, 6] = this.textBox202.Text;
            board[13, 7] = this.textBox203.Text;
            board[13, 8] = this.textBox204.Text;
            board[13, 9] = this.textBox205.Text;
            board[13, 10] = this.textBox206.Text;
            board[13, 11] = this.textBox207.Text;
            board[13, 12] = this.textBox208.Text;
            board[13, 13] = this.textBox209.Text;
            board[13, 14] = this.textBox210.Text;
            board[14, 0] = this.textBox211.Text;
            board[14, 1] = this.textBox212.Text;
            board[14, 2] = this.textBox213.Text;
            board[14, 3] = this.textBox214.Text;
            board[14, 4] = this.textBox215.Text;
            board[14, 5] = this.textBox216.Text;
            board[14, 6] = this.textBox217.Text;
            board[14, 7] = this.textBox218.Text;
            board[14, 8] = this.textBox219.Text;
            board[14, 9] = this.textBox220.Text;
            board[14, 10] = this.textBox221.Text;
            board[14, 11] = this.textBox222.Text;
            board[14, 12] = this.textBox223.Text;
            board[14, 13] = this.textBox224.Text;
            board[14, 14] = this.textBox225.Text;

            for (int i = 0; i < 15; i++)
                for (int j = 0; j < 15; j++)
                {
                    if (!"ABCDEFGHIJKLMNOPQRSTUVWXYZ*".Contains(board[i, j]) || board[i, j] == "")
                        board[i, j] = " ";
                    game.board[i, j] = board[i, j].ToCharArray()[0];
                }
        }

        //Get board from char[,], put to textBoxes
        private void putBoard()
        {
            this.textBox1.Text = game.board[0, 0].ToString();
            this.textBox2.Text = game.board[0, 1].ToString();
            this.textBox3.Text = game.board[0, 2].ToString();
            this.textBox4.Text = game.board[0, 3].ToString();
            this.textBox5.Text = game.board[0, 4].ToString();
            this.textBox6.Text = game.board[0, 5].ToString();
            this.textBox7.Text = game.board[0, 6].ToString();
            this.textBox8.Text = game.board[0, 7].ToString();
            this.textBox9.Text = game.board[0, 8].ToString();
            this.textBox10.Text = game.board[0, 9].ToString();
            this.textBox11.Text = game.board[0, 10].ToString();
            this.textBox12.Text = game.board[0, 11].ToString();
            this.textBox13.Text = game.board[0, 12].ToString();
            this.textBox14.Text = game.board[0, 13].ToString();
            this.textBox15.Text = game.board[0, 14].ToString();
            this.textBox16.Text = game.board[1, 0].ToString();
            this.textBox17.Text = game.board[1, 1].ToString();
            this.textBox18.Text = game.board[1, 2].ToString();
            this.textBox19.Text = game.board[1, 3].ToString();
            this.textBox20.Text = game.board[1, 4].ToString();
            this.textBox21.Text = game.board[1, 5].ToString();
            this.textBox22.Text = game.board[1, 6].ToString();
            this.textBox23.Text = game.board[1, 7].ToString();
            this.textBox24.Text = game.board[1, 8].ToString();
            this.textBox25.Text = game.board[1, 9].ToString();
            this.textBox26.Text = game.board[1, 10].ToString();
            this.textBox27.Text = game.board[1, 11].ToString();
            this.textBox28.Text = game.board[1, 12].ToString();
            this.textBox29.Text = game.board[1, 13].ToString();
            this.textBox30.Text = game.board[1, 14].ToString();
            this.textBox31.Text = game.board[2, 0].ToString();
            this.textBox32.Text = game.board[2, 1].ToString();
            this.textBox33.Text = game.board[2, 2].ToString();
            this.textBox34.Text = game.board[2, 3].ToString();
            this.textBox35.Text = game.board[2, 4].ToString();
            this.textBox36.Text = game.board[2, 5].ToString();
            this.textBox37.Text = game.board[2, 6].ToString();
            this.textBox38.Text = game.board[2, 7].ToString();
            this.textBox39.Text = game.board[2, 8].ToString();
            this.textBox40.Text = game.board[2, 9].ToString();
            this.textBox41.Text = game.board[2, 10].ToString();
            this.textBox42.Text = game.board[2, 11].ToString();
            this.textBox43.Text = game.board[2, 12].ToString();
            this.textBox44.Text = game.board[2, 13].ToString();
            this.textBox45.Text = game.board[2, 14].ToString();
            this.textBox46.Text = game.board[3, 0].ToString();
            this.textBox47.Text = game.board[3, 1].ToString();
            this.textBox48.Text = game.board[3, 2].ToString();
            this.textBox49.Text = game.board[3, 3].ToString();
            this.textBox50.Text = game.board[3, 4].ToString();
            this.textBox51.Text = game.board[3, 5].ToString();
            this.textBox52.Text = game.board[3, 6].ToString();
            this.textBox53.Text = game.board[3, 7].ToString();
            this.textBox54.Text = game.board[3, 8].ToString();
            this.textBox55.Text = game.board[3, 9].ToString();
            this.textBox56.Text = game.board[3, 10].ToString();
            this.textBox57.Text = game.board[3, 11].ToString();
            this.textBox58.Text = game.board[3, 12].ToString();
            this.textBox59.Text = game.board[3, 13].ToString();
            this.textBox60.Text = game.board[3, 14].ToString();
            this.textBox61.Text = game.board[4, 0].ToString();
            this.textBox62.Text = game.board[4, 1].ToString();
            this.textBox63.Text = game.board[4, 2].ToString();
            this.textBox64.Text = game.board[4, 3].ToString();
            this.textBox65.Text = game.board[4, 4].ToString();
            this.textBox66.Text = game.board[4, 5].ToString();
            this.textBox67.Text = game.board[4, 6].ToString();
            this.textBox68.Text = game.board[4, 7].ToString();
            this.textBox69.Text = game.board[4, 8].ToString();
            this.textBox70.Text = game.board[4, 9].ToString();
            this.textBox71.Text = game.board[4, 10].ToString();
            this.textBox72.Text = game.board[4, 11].ToString();
            this.textBox73.Text = game.board[4, 12].ToString();
            this.textBox74.Text = game.board[4, 13].ToString();
            this.textBox75.Text = game.board[4, 14].ToString();
            this.textBox76.Text = game.board[5, 0].ToString();
            this.textBox77.Text = game.board[5, 1].ToString();
            this.textBox78.Text = game.board[5, 2].ToString();
            this.textBox79.Text = game.board[5, 3].ToString();
            this.textBox80.Text = game.board[5, 4].ToString();
            this.textBox81.Text = game.board[5, 5].ToString();
            this.textBox82.Text = game.board[5, 6].ToString();
            this.textBox83.Text = game.board[5, 7].ToString();
            this.textBox84.Text = game.board[5, 8].ToString();
            this.textBox85.Text = game.board[5, 9].ToString();
            this.textBox86.Text = game.board[5, 10].ToString();
            this.textBox87.Text = game.board[5, 11].ToString();
            this.textBox88.Text = game.board[5, 12].ToString();
            this.textBox89.Text = game.board[5, 13].ToString();
            this.textBox90.Text = game.board[5, 14].ToString();
            this.textBox91.Text = game.board[6, 0].ToString();
            this.textBox92.Text = game.board[6, 1].ToString();
            this.textBox93.Text = game.board[6, 2].ToString();
            this.textBox94.Text = game.board[6, 3].ToString();
            this.textBox95.Text = game.board[6, 4].ToString();
            this.textBox96.Text = game.board[6, 5].ToString();
            this.textBox97.Text = game.board[6, 6].ToString();
            this.textBox98.Text = game.board[6, 7].ToString();
            this.textBox99.Text = game.board[6, 8].ToString();
            this.textBox100.Text = game.board[6, 9].ToString();
            this.textBox101.Text = game.board[6, 10].ToString();
            this.textBox102.Text = game.board[6, 11].ToString();
            this.textBox103.Text = game.board[6, 12].ToString();
            this.textBox104.Text = game.board[6, 13].ToString();
            this.textBox105.Text = game.board[6, 14].ToString();
            this.textBox106.Text = game.board[7, 0].ToString();
            this.textBox107.Text = game.board[7, 1].ToString();
            this.textBox108.Text = game.board[7, 2].ToString();
            this.textBox109.Text = game.board[7, 3].ToString();
            this.textBox110.Text = game.board[7, 4].ToString();
            this.textBox111.Text = game.board[7, 5].ToString();
            this.textBox112.Text = game.board[7, 6].ToString();
            this.textBox113.Text = game.board[7, 7].ToString();
            this.textBox114.Text = game.board[7, 8].ToString();
            this.textBox115.Text = game.board[7, 9].ToString();
            this.textBox116.Text = game.board[7, 10].ToString();
            this.textBox117.Text = game.board[7, 11].ToString();
            this.textBox118.Text = game.board[7, 12].ToString();
            this.textBox119.Text = game.board[7, 13].ToString();
            this.textBox120.Text = game.board[7, 14].ToString();
            this.textBox121.Text = game.board[8, 0].ToString();
            this.textBox122.Text = game.board[8, 1].ToString();
            this.textBox123.Text = game.board[8, 2].ToString();
            this.textBox124.Text = game.board[8, 3].ToString();
            this.textBox125.Text = game.board[8, 4].ToString();
            this.textBox126.Text = game.board[8, 5].ToString();
            this.textBox127.Text = game.board[8, 6].ToString();
            this.textBox128.Text = game.board[8, 7].ToString();
            this.textBox129.Text = game.board[8, 8].ToString();
            this.textBox130.Text = game.board[8, 9].ToString();
            this.textBox131.Text = game.board[8, 10].ToString();
            this.textBox132.Text = game.board[8, 11].ToString();
            this.textBox133.Text = game.board[8, 12].ToString();
            this.textBox134.Text = game.board[8, 13].ToString();
            this.textBox135.Text = game.board[8, 14].ToString();
            this.textBox136.Text = game.board[9, 0].ToString();
            this.textBox137.Text = game.board[9, 1].ToString();
            this.textBox138.Text = game.board[9, 2].ToString();
            this.textBox139.Text = game.board[9, 3].ToString();
            this.textBox140.Text = game.board[9, 4].ToString();
            this.textBox141.Text = game.board[9, 5].ToString();
            this.textBox142.Text = game.board[9, 6].ToString();
            this.textBox143.Text = game.board[9, 7].ToString();
            this.textBox144.Text = game.board[9, 8].ToString();
            this.textBox145.Text = game.board[9, 9].ToString();
            this.textBox146.Text = game.board[9, 10].ToString();
            this.textBox147.Text = game.board[9, 11].ToString();
            this.textBox148.Text = game.board[9, 12].ToString();
            this.textBox149.Text = game.board[9, 13].ToString();
            this.textBox150.Text = game.board[9, 14].ToString();
            this.textBox151.Text = game.board[10, 0].ToString();
            this.textBox152.Text = game.board[10, 1].ToString();
            this.textBox153.Text = game.board[10, 2].ToString();
            this.textBox154.Text = game.board[10, 3].ToString();
            this.textBox155.Text = game.board[10, 4].ToString();
            this.textBox156.Text = game.board[10, 5].ToString();
            this.textBox157.Text = game.board[10, 6].ToString();
            this.textBox158.Text = game.board[10, 7].ToString();
            this.textBox159.Text = game.board[10, 8].ToString();
            this.textBox160.Text = game.board[10, 9].ToString();
            this.textBox161.Text = game.board[10, 10].ToString();
            this.textBox162.Text = game.board[10, 11].ToString();
            this.textBox163.Text = game.board[10, 12].ToString();
            this.textBox164.Text = game.board[10, 13].ToString();
            this.textBox165.Text = game.board[10, 14].ToString();
            this.textBox166.Text = game.board[11, 0].ToString();
            this.textBox167.Text = game.board[11, 1].ToString();
            this.textBox168.Text = game.board[11, 2].ToString();
            this.textBox169.Text = game.board[11, 3].ToString();
            this.textBox170.Text = game.board[11, 4].ToString();
            this.textBox171.Text = game.board[11, 5].ToString();
            this.textBox172.Text = game.board[11, 6].ToString();
            this.textBox173.Text = game.board[11, 7].ToString();
            this.textBox174.Text = game.board[11, 8].ToString();
            this.textBox175.Text = game.board[11, 9].ToString();
            this.textBox176.Text = game.board[11, 10].ToString();
            this.textBox177.Text = game.board[11, 11].ToString();
            this.textBox178.Text = game.board[11, 12].ToString();
            this.textBox179.Text = game.board[11, 13].ToString();
            this.textBox180.Text = game.board[11, 14].ToString();
            this.textBox181.Text = game.board[12, 0].ToString();
            this.textBox182.Text = game.board[12, 1].ToString();
            this.textBox183.Text = game.board[12, 2].ToString();
            this.textBox184.Text = game.board[12, 3].ToString();
            this.textBox185.Text = game.board[12, 4].ToString();
            this.textBox186.Text = game.board[12, 5].ToString();
            this.textBox187.Text = game.board[12, 6].ToString();
            this.textBox188.Text = game.board[12, 7].ToString();
            this.textBox189.Text = game.board[12, 8].ToString();
            this.textBox190.Text = game.board[12, 9].ToString();
            this.textBox191.Text = game.board[12, 10].ToString();
            this.textBox192.Text = game.board[12, 11].ToString();
            this.textBox193.Text = game.board[12, 12].ToString();
            this.textBox194.Text = game.board[12, 13].ToString();
            this.textBox195.Text = game.board[12, 14].ToString();
            this.textBox196.Text = game.board[13, 0].ToString();
            this.textBox197.Text = game.board[13, 1].ToString();
            this.textBox198.Text = game.board[13, 2].ToString();
            this.textBox199.Text = game.board[13, 3].ToString();
            this.textBox200.Text = game.board[13, 4].ToString();
            this.textBox201.Text = game.board[13, 5].ToString();
            this.textBox202.Text = game.board[13, 6].ToString();
            this.textBox203.Text = game.board[13, 7].ToString();
            this.textBox204.Text = game.board[13, 8].ToString();
            this.textBox205.Text = game.board[13, 9].ToString();
            this.textBox206.Text = game.board[13, 10].ToString();
            this.textBox207.Text = game.board[13, 11].ToString();
            this.textBox208.Text = game.board[13, 12].ToString();
            this.textBox209.Text = game.board[13, 13].ToString();
            this.textBox210.Text = game.board[13, 14].ToString();
            this.textBox211.Text = game.board[14, 0].ToString();
            this.textBox212.Text = game.board[14, 1].ToString();
            this.textBox213.Text = game.board[14, 2].ToString();
            this.textBox214.Text = game.board[14, 3].ToString();
            this.textBox215.Text = game.board[14, 4].ToString();
            this.textBox216.Text = game.board[14, 5].ToString();
            this.textBox217.Text = game.board[14, 6].ToString();
            this.textBox218.Text = game.board[14, 7].ToString();
            this.textBox219.Text = game.board[14, 8].ToString();
            this.textBox220.Text = game.board[14, 9].ToString();
            this.textBox221.Text = game.board[14, 10].ToString();
            this.textBox222.Text = game.board[14, 11].ToString();
            this.textBox223.Text = game.board[14, 12].ToString();
            this.textBox224.Text = game.board[14, 13].ToString();
            this.textBox225.Text = game.board[14, 14].ToString();
        }

        private void panel1_Paint(object sender, PaintEventArgs e)
        {
            Graphics dc = e.Graphics;
            
        }
    }
}
