﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Scrabble
{
    public class Board
    {
        public char[,] board = new char[15, 15];
        private char[,] backup = new char[15, 15];
        public class result : IComparable
        {
            public int r;
            public int c;
            public string word;
            public bool Hpos;
            public int pts;

            int IComparable.CompareTo(object obj)
            {
                result c = (result) obj;
                return c.pts - this.pts;
            }
        }
        private class runPacket : IComparable
        {
            public int priority;
            public string codeword;
            public string[] crossCheck;
            public int r;
            public int c;

            int IComparable.CompareTo(object obj)
            {
                runPacket c = (runPacket) obj;
                return c.priority - this.priority;
            }

        }
        public ArrayList results;
        public HashSet<string> dictionary = new HashSet<string>();
        public string letters = "";
        private CrossCheck cross;
        public int percentage = 0;
       
        public Board()
        {
            for (int i=0; i<15; i++)
                for (int j=0; j<15; j++)
                    board[i,j] = ' ';
        }

        /*
         * Notes: 
         *  - char[,] board must be initiallized first with letters and spaces
         *  - dictionary must be filled with the dictionary to be used
         *  - string letters must be complete
         * 
         * Take a given Scrabble board and dictionary and stores all possible 
         * word plays in the ArrayList results.
        */ 
        public void calculateResults()
        {
            percentage = 0;
            cross = new CrossCheck(board, dictionary);
            results = new ArrayList();

            //First word check
            if (board[7, 7] == ' ')
                firstMove();

            //
            //Create all crossChecks and codeWords
            //
            List<runPacket> queue = new List<runPacket>();
            //For each row and column
            for (int i=0; i<15; i++)
            {
                string row = "";
                string col = "";
                int r = 0;
                int c = 0;

                //Create codeWord
                for (int j=0; j<15; j++)
                {
                    row += board[i,j];
                    if (board[i, j] != ' ')
                        r++;
                    col += board[j,i];
                    if (board[j, i] != ' ')
                        c++;
                }

                //Create crossCheck
                string[] rowC = cross.createCrossCheck(i,-1);
                string[] colC = cross.createCrossCheck(-1,i);


                //Store crossCheck and codeword in runQueue... if it is not an empty row/column
                if (!(col == "               " && cross.emptyCol))
                {
                    runPacket p = new runPacket();
                    p.priority = c;
                    p.codeword = col;
                    p.crossCheck = colC;
                    p.r = -1;
                    p.c = i;
                    queue.Add(p);
                }
                if (!(row == "               " && cross.emptyRow))
                {
                    runPacket p = new runPacket();
                    p.priority = r;
                    p.codeword = row;
                    p.crossCheck = rowC;
                    p.r = i;
                    p.c = -1;
                    queue.Add(p);
                }
            }
            queue.Sort();

            int largestPacket = 6;
            foreach (runPacket packet in queue)
            {
                percentage += (100 - percentage)/8;

                //If this packet needs a dictionary that is possibly 
                //half the size of of the current, reduce the dictionary
                if (packet.priority < largestPacket)
                {
                    largestPacket = packet.priority;

                    //Get list of words to remove
                    HashSet<string> wordsToRemove = new HashSet<string>();
                    foreach (string w in dictionary)
                        if (!Words.composedOf(w, letters + "******".Substring(0,largestPacket)))
                            wordsToRemove.Add(w);

                    //Remove words
                    foreach (string w in wordsToRemove)
                        dictionary.Remove(w);
                }

                if (packet.c == -1)
                {
                    LinkedList<string> r = dictionaryRun(packet.codeword, packet.crossCheck);

                    //Store results from this row
                    foreach (string s in r)
                    {
                        result newResult = new result();
                        newResult.word = s.Trim();
                        newResult.r = packet.r;
                        newResult.c = s.IndexOf(newResult.word.Substring(0, 1));
                        newResult.Hpos = true;
                        newResult.pts = Words.value(s.ToCharArray(), packet.codeword.ToCharArray(), packet.crossCheck, packet.r, packet.c, letters);

                        results.Add(newResult);
                    }
                }
                else
                {
                    LinkedList<string> c = dictionaryRun(packet.codeword, packet.crossCheck);

                    //Store results from this column
                    foreach (string s in c)
                    {
                        result newResult = new result();
                        newResult.word = s.Trim();
                        newResult.c = packet.c;
                        newResult.r = s.IndexOf(newResult.word.Substring(0, 1));
                        newResult.Hpos = false;
                        newResult.pts = Words.value(s.ToCharArray(), packet.codeword.ToCharArray(), packet.crossCheck, packet.r, packet.c, letters);

                        results.Add(newResult);
                    }
                }
            }

            results.Sort();
        }

        /*
         * Overload method
        */
        public void placeResult(int r, int c, string word, bool Hpos)
        {
            result res = new result();
            res.r = r;
            res.c = c;
            res.word = word;
            res.Hpos = Hpos;
            placeResult(res);
        }

        /*
         * Places a result on the board
         * 
         * Note: To be run after results have been calculated
        */
        public void placeResult(result res)
        {
            //Create backup
            for (int i = 0; i < 15; i++)
                for (int j = 0; j < 15; j++)
                    backup[i, j] = board[i, j];

            if (res.Hpos)
                placeWordH(res.r, res.c, res.word);
            else
                placeWordV(res.r, res.c, res.word);
        }

        /*
         * 
        */
        public void restore()
        {
            for (int i = 0; i < 15; i++)
                for (int j = 0; j < 15; j++)
                    board[i, j] = backup[i, j];
        }


        //PRIVATE HELPER METHODS
        private void firstMove()
        {
            //Run through entire dictionary
            foreach (string word in dictionary)
            {
                if (Words.composedOf(word, letters))
                {
                    result res = new result();
                    res.word = word;
                    res.r = 7;
                    res.Hpos = true;
                    res.pts = 0;

                    //Find highest placement
                    for (int i = 8-word.Length; i < 7; i++)
                    {
                        string s = "       ".Substring(0, i) + word + "       ".Substring(0, 15-i-word.Length);
                        int val = Words.value(s.ToCharArray(), "               ".ToCharArray(), new string[15], 7, -1, letters);
                        if (val > res.pts)
                        {
                            res.pts = val;
                            res.c = i;
                        }
                    }

                    results.Add(res);
                }
            }
        }

        /*
         * Takes a given codeWord and crossCheck and tests every word in the dictionary
         * for valid placements.  This takes a lot of processing time, especially with
         * dictionaries above 100,000 words.
        */
        private LinkedList<string> dictionaryRun(string codeWord, string[] crossCheck)
        {
            LinkedList<string> res = new LinkedList<string>();

            foreach (string word in dictionary)
            {
                string[] pos = Words.findPositions(codeWord, word, letters);

                foreach (string position in pos)
                    if (cross.crossCheck(crossCheck, codeWord, position))
                        res.AddLast(position);
            }

            return res;
        }
        
        /*
         * Places a result on the board horizontally from a starting location
         * 
         * Note: To be run after results have been calculated 
        */
        private void placeWordH(int r, int c, string word)
        {
            int i = 0;
            foreach (char l in word)
                board[r, c + i++] = l;
        }

        /*
         * Places a result on the board vertically from a starting location
         * 
         * Note: To be run after results have been calculated 
        */
        private void placeWordV(int r, int c, string word)
        {
            int i = 0;
            foreach (char l in word)
                board[r + i++, c] = l;
        }

    }
}
