﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Scrabble
{
    public static class Words
    {
        static Hashtable alphabet = new Hashtable(26);

        /*
         * Checks to see if the characters in the string "word" 
         * are part of a subset of the string "letters"
         * 
         * Returns true only if word is a subset of letters AND
         * word uses at least one char from the first 7 characters 
         * in "letters", otherwise, returns false
         * 
         * Notes: 
         * - letters must not contain " " in the first 7 entries
         * - * is a single character wildcard
        */
        public static bool composedOf(string word, string letters)
        {
            foreach (char w in word)
            {
                //Run through each character in word and make sure it is the set of letters
                if (letters.Contains(w) || letters.Contains('*'))
                {
                    //Find the index of the letter we're using
                    int i = letters.IndexOf(w);
                    if (i == -1)
                        i = letters.IndexOf('*');

                    //Mark that a letter has been used
                    letters = Scrabble.Words.replace(letters, ' ', i);

                    //Go to next character in word
                    continue;
                }
                else
                    return false;
            }

            //Check to see if one of the first 7 letters was used
            if (letters.Substring(0, 7).Contains(' '))
            {
                return true;
            }
            else
                return false;
        }

        /*
         * Finds the value of laying a given word on the board
        */
        public static int value(char[] wordPosition, char[] codeWord, string[] crossCheck, int r, int c, string letters)
        {
            int value = 0;
            int mainWordValue = 0;
            int numberOfLetters = 0;
            int multiplierRepeatBonus = 1;
            int multiplierBonus;
            int letterBonus;
            int kc, kr;
            if (r == -1)
            {
                kc = 1;
                kr = 0;
            }
            else
            {
                kr = 1;
                kc = 0;
            }

            //For each letter of the word
            for (int i = 0; i < wordPosition.Length; i++)
            {
                if (wordPosition[i] == ' ') continue;

                //Keep running tally of letters used
                if (codeWord[i] == ' ')
                {
                    numberOfLetters++;

                    //If the letter is not a letter, then it must be a * wildcard
                    if (!letters.Contains(wordPosition[i]))
                    {
                        //Replace wordPosition[i] with *
                        wordPosition[i] = '*';
                        //Erase * from letters
                        letters = Words.replace(letters, ' ', letters.IndexOf('*'));
                    }
                    else
                        //Erase letter that was used
                        letters = Words.replace(letters, ' ', letters.IndexOf(wordPosition[i]));
                }
                

                //Determine bonus
                multiplierBonus = mBonus(r*kr + i*kc, c*kc + i*kr, codeWord[i]);
                letterBonus = lBonus(r*kr + i*kc, c*kc + i*kr, codeWord[i]);
                multiplierRepeatBonus *= multiplierBonus;

                //Determine wheather to add words crossing this one to the value
                if (crossCheck[i] != null)
                    value += findCrossValue(wordPosition[i], crossCheck[i], multiplierBonus, letterBonus);

                //Add value of current letter
                mainWordValue += letterValue(wordPosition[i]) * letterBonus;
            }

            //Add value of main word
            value += mainWordValue * multiplierRepeatBonus;

            //Add 7 letter bonus
            if (numberOfLetters == 7)
                value += 50;

            return value;
        }

        /*
         *  Determines the possible positions of the dictionary word into the code word.  If there
         *  are no possible positions for the dictionary word into the code word, returns an array of
         *  size 1 with the value of " "
         * 
         *  Example #1
         *    codeWord: "    t    "
         *    dictionaryWord: "start"
         *    findPosition(1) = "start    "
         *    findPosition(2) = "   start "
         * 
         *  Example #2
         *    codeWord: "    end  "
         *    dictionaryWord: "end"
         *    findPosition(1) = "end      "
         * 
         *  Example #3
         *    codeWord: "   end  "
         *    dictionaryWord: "end"
         *    findPosition = void
        */
        public static string[] findPositions(string codeWord, string dictionaryWord, string letters)
        {
            List<string> positions = new List<string>();
            int length = codeWord.Length - dictionaryWord.Length;

            for (int i = 0; i <= length; i++)
            {
                string pos = dictionaryWord.PadLeft(i + dictionaryWord.Length, ' ').PadRight(15, ' ');

                //Check char to left and right of dictionaryWord to make sure it is a ' '
                if (i > 0)
                    if (' ' != codeWord.ToCharArray()[i - 1]) continue;
                if (i < length)
                    if (' ' != codeWord.ToCharArray()[dictionaryWord.Length + i]) continue;

                //Check each non-space characters of pos with the codeWord
                bool match = true;
                char[] p = pos.ToCharArray();
                char[] c = codeWord.ToCharArray();
                string extra = "";
                for (int j = i; j < dictionaryWord.Length + i; j++)
                {
                    if (p[j] != c[j])
                    {
                        if (c[j] != ' ')
                        {
                            match = false;
                            break;
                        }
                    }
                    else
                        extra += c[j];
                }


                if (!match) continue;

                //Check that the word can be placed
                match = Scrabble.Words.composedOf(dictionaryWord, String.Concat(letters, extra));

                if (match)
                    positions.Add(pos);
            }

            return positions.ToArray();
        }

        //PRIVATE HELPER METHODS
        /*
         * Returns a string that has one letter replaced with a string.
         * 
         * Ex: replace("hello", " ", 2) returns "he lo"
        */
        public static string replace(string word, char l, int index)
        {
            return String.Concat(word.Substring(0, index), l, word.Substring(index + 1, word.Length - index - 1));
        }

        /*
         * Returns a string of the same length with the characters of "word"
         * in randomized order.
        */
        public static string scramble(string word)
        {
            string ret = "";
            Random numGen = new Random();
            int rand;

            for (int i = 0; i < word.Length; i++)
            {
                rand = numGen.Next(word.Length);
                ret += word.Substring(rand, 1);
                word = word.Substring(0, rand) + word.Substring(rand+1, word.Length - rand - 1);
            }

            return ret;
        }

        /*
         * Determines the value of this cross word.  The bonus, if any, 
         * is applied to the " " which is represented by the character input
        */
        private static int findCrossValue(char l, string crossCheck, int multiplierBonus, int letterBonus)
        {
            int value = 0;

            foreach (char c in crossCheck)
                if (c == ' ')
                    value += letterValue(l) * letterBonus;
                else
                    value += letterValue(c);

            return value * multiplierBonus;
        }

        /*
         * Calculates the multiplier bonus for a given tile
         */
        public static int mBonus(int r, int c, char l)
        {
            r = r+1;
            c = c+1;

            //If the bonus has already been played, return 1
            if (l != ' ')
                return 1;

            //Check for triple word bonus
            if (r % 7 == 1)
                if (c % 7 == 1)
                    return 3;

            //Check for double word bonus
            if ((1 < r && r < 6) && (c == r || c == 16 - r))
                return 2;

            if ((10 < r && r < 15) && (c == 16 - r || c == r))
                return 2;

            return 1;
        }

        /*
         * Calculates the letter bonus on a given square of the board.  
         * The location on the board is either Cells(r, l) or Cells(l, c)
         * 
         * The code word is given, as a " " must exist in order for a bonus to be present
        */
        public static int lBonus(int r, int c, char l)
        {
            r = r + 1;
            c = c + 1;

            //If the bonus has already been played, return 1
            if (l != ' ')
                return 1;

            //Check for triple letter bonus
            if (r % 4 == 2)
                if (c % 4 == 2)
                    if (!(r * c == 4 || r * c == 196 || r * c == 28))
                        return 3;

            //Check for double letter bonus
            if (r % 8 == 4 && c % 7 == 1)
                return 2;
            if (c % 8 == 4 && r % 7 == 1)
                return 2;
            if ((r == 7 || r == 9) && (c == 3 || c == 7 || c == 9 || c == 13))
                return 2;
            if ((c == 7 || c == 9) && (r == 3 || r == 13))
                return 2;

            //Return default value
            return 1;
        }

        /*
         * Returns the official Scrabble value for a letter
        */
        public static int letterValue(char l)
        {
            //Load the alphabet if needed
            if (alphabet.Count == 0)
            {
                alphabet.Add('A', 1);
                alphabet.Add('B', 3);
                alphabet.Add('C', 3);
                alphabet.Add('D', 2);
                alphabet.Add('E', 1);
                alphabet.Add('F', 4);
                alphabet.Add('G', 2);
                alphabet.Add('H', 4);
                alphabet.Add('I', 1);
                alphabet.Add('J', 8);
                alphabet.Add('K', 5);
                alphabet.Add('L', 1);
                alphabet.Add('M', 3);
                alphabet.Add('N', 1);
                alphabet.Add('O', 1);
                alphabet.Add('P', 3);
                alphabet.Add('Q', 10);
                alphabet.Add('R', 1);
                alphabet.Add('S', 1);
                alphabet.Add('T', 1);
                alphabet.Add('U', 1);
                alphabet.Add('V', 4);
                alphabet.Add('W', 4);
                alphabet.Add('X', 8);
                alphabet.Add('Y', 4);
                alphabet.Add('Z', 10);
            }

            if (alphabet.ContainsKey(l))
                return Convert.ToInt32(alphabet[l]);
            else
                return 0;
        }

        public static string letterValueS(string word)
        {
            if (word.Length == 0)
                return "";
            else
            {
                int i = letterValue(word.ToCharArray()[0]);
                if (i == 0)
                    return "";
                else
                    return Convert.ToString(i);
            }
        }
    }
}
